==> seedsui-react-2.6.2.tgz: package/es/BiGauge/BiGauge.js <==
var _class, _temp;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';

var BiGauge = (_temp = _class = function (_Component) {
  _inherits(BiGauge, _Component);

  function BiGauge(props, context) {
    _classCallCheck(this, BiGauge);

    var _this = _possibleConstructorReturn(this, _Component.call(this, props, context));

    _this.getDuration = function () {
      var _this$props = _this.props,
          duration = _this$props.duration,
          rotate = _this$props.rotate;

      return duration / 270 * rotate;
    };

    _this.getRotate = function () {
      var rotate = _this.props.rotate;

      return rotate > 270 ? 270 : rotate;
    };

    _this.getBgLvl = function () {
      var rotate = _this.props.rotate;

      var lvl = Math.round(rotate / 27);
      return lvl > 10 ? 10 : 1;
    };

    _this.aniRotate = function () {
      // 时长
      var duration = _this.getDuration();
      // 旋转
      var rotate = _this.getRotate();
      // 背景
      var bgLvl = 'bg' + _this.getBgLvl();
      setTimeout(function () {
        if (_this.$el) {
          _this.$el.style.WebkitAnimationDuration = duration + 'ms';
          _this.$el.classList.add(bgLvl);
        }
        if (_this.$elPointer) {
          _this.$elPointer.style.WebkitTransitionDuration = duration + 'ms';
          _this.$elPointer.style.WebkitTransform = 'rotate(' + rotate + 'deg)';
        }
      }, _this.props.delay);
    };

    return _this;
  }
  // 只有延迟100毫秒动画才会生效


  BiGauge.prototype.render = function render() {
    var _this2 = this;

    var _props = this.props,
        className = _props.className,
        style = _props.style,
        children = _props.children,
        captionClassName = _props.captionClassName,
        captionStyle = _props.captionStyle;
    // 动画旋转

    this.aniRotate();
    return React.createElement(
      'div',
      { ref: function ref(el) {
          _this2.$el = el;
        }, className: 'bi-gauge-box' + (className ? ' ' + className : ''), style: style },
      React.createElement(
        'div',
        { className: 'bi-gauge' },
        React.createElement('div', { ref: function ref(el) {
            _this2.$elPointer = el;
          }, className: 'bi-gauge-pointer' }),
        React.createElement(
          'div',
          { className: 'bi-gauge-caption' + (captionClassName ? ' ' + captionClassName : ''), style: captionStyle },
          children
        )
      )
    );
  };

  return BiGauge;
}(Component), _class.defaultProps = {
  duration: 1000,
  rotate: 0,
  delay: 100
}, _temp);
export { BiGauge as default };
BiGauge.propTypes = process.env.NODE_ENV !== "production" ? {
  duration: PropTypes.number, // 时长
  rotate: PropTypes.number, // 最大270
  delay: PropTypes.number, // 延时

  className: PropTypes.string,
  style: PropTypes.object,
  children: PropTypes.node,
  captionClassName: PropTypes.string,
  captionStyle: PropTypes.object
} : {};

==> seedsui-react-3.7.9.tgz: package/es/BiGauge/BiGauge.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';

var BiGauge = (_temp = _class = function (_Component) {
  _inherits(BiGauge, _Component);

  function BiGauge(props, context) {
    _classCallCheck(this, BiGauge);

    var _this = _possibleConstructorReturn(this, _Component.call(this, props, context));

    _this.getDuration = function () {
      var _this$props = _this.props,
          duration = _this$props.duration,
          rotate = _this$props.rotate;

      return duration / 270 * rotate;
    };

    _this.getRotate = function () {
      var rotate = _this.props.rotate;

      return rotate > 270 ? 270 : rotate;
    };

    _this.getBgLvl = function () {
      var rotate = _this.props.rotate;

      var lvl = Math.round(rotate / 27);
      return lvl > 10 ? 10 : 1;
    };

    _this.aniRotate = function () {
      // 时长
      var duration = _this.getDuration();
      // 旋转
      var rotate = _this.getRotate();
      // 背景
      var bgLvl = 'bg' + _this.getBgLvl();
      setTimeout(function () {
        if (_this.$el) {
          _this.$el.style.WebkitAnimationDuration = duration + 'ms';
          _this.$el.classList.add(bgLvl);
        }
        if (_this.$elPointer) {
          _this.$elPointer.style.WebkitTransitionDuration = duration + 'ms';
          _this.$elPointer.style.WebkitTransform = 'rotate(' + rotate + 'deg)';
        }
      }, _this.props.delay);
    };

    return _this;
  }
  // 只有延迟100毫秒动画才会生效


  BiGauge.prototype.render = function render() {
    var _this2 = this;

    var _props = this.props,
        duration = _props.duration,
        rotate = _props.rotate,
        delay = _props.delay,
        _props$captionAttribu = _props.captionAttribute,
        captionAttribute = _props$captionAttribu === undefined ? {} : _props$captionAttribu,
        children = _props.children,
        others = _objectWithoutProperties(_props, ['duration', 'rotate', 'delay', 'captionAttribute', 'children']);
    // 动画旋转


    this.aniRotate();
    return React.createElement(
      'div',
      _extends({ ref: function ref(el) {
          _this2.$el = el;
        } }, others, { className: 'bi-gauge-box' + (others.className ? ' ' + others.className : '') }),
      React.createElement(
        'div',
        { className: 'bi-gauge' },
        React.createElement('div', { ref: function ref(el) {
            _this2.$elPointer = el;
          }, className: 'bi-gauge-pointer' }),
        React.createElement(
          'div',
          _extends({}, captionAttribute, { className: 'bi-gauge-caption' + (captionAttribute.className ? ' ' + captionAttribute.className : '') }),
          children
        )
      )
    );
  };

  return BiGauge;
}(Component), _class.defaultProps = {
  duration: 1000,
  rotate: 0,
  delay: 100
}, _temp);
export { BiGauge as default };
BiGauge.propTypes = process.env.NODE_ENV !== "production" ? {
  duration: PropTypes.number, // 时长
  rotate: PropTypes.number, // 最大270
  delay: PropTypes.number, // 延时

  captionAttribute: PropTypes.object,
  children: PropTypes.node
} : {};
